@@ -18,7 +18,7 @@ use File::Path ();
 use Cwd ();
 use Config;
 
-our $VERSION = '0.306';
+our $VERSION = '0.350';
 
 use constant WIN32 => $^O eq 'MSWin32';
 
@@ -33,6 +33,9 @@ sub new {
         cpanmetadb => "http://cpanmetadb.plackperl.org/v1.0/",
         mirror => ["https://cpan.metacpan.org/"],
         retry => 1,
+        configure_timeout => 60,
+        build_timeout => 3600,
+        test_timeout => 1800,
         %option
     }, $class;
 }
@@ -62,7 +65,12 @@ sub parse_options {
         "man-pages" => \($self->{man_pages}),
         "home=s" => \($self->{home}),
         "with-develop" => \($self->{with_develop}),
+        "with-recommends" => \($self->{with_recommends}),
+        "with-suggests" => \($self->{with_suggests}),
         "retry!" => \($self->{retry}),
+        "configure-timeout=i" => \($self->{configure_timeout}),
+        "build-timeout=i" => \($self->{build_timeout}),
+        "test-timeout=i" => \($self->{test_timeout}),
     or exit 1;
 
     $self->{local_lib} = $self->maybe_abs($self->{local_lib}) unless $self->{global};
@@ -199,6 +207,9 @@ sub cmd_install {
         resolver  => $self->generate_resolver,
         man_pages => $self->{man_pages},
         retry     => $self->{retry},
+        configure_timeout => $self->{configure_timeout},
+        build_timeout     => $self->{build_timeout},
+        test_timeout      => $self->{test_timeout},
         ($self->{global} ? () : (local_lib => $self->{local_lib})),
     );
 
@@ -380,7 +391,10 @@ sub load_cpanfile {
     my $prereqs = $cpanfile->prereqs_with;
     my $phases = [qw(build test runtime)];
     push @$phases, 'develop' if $self->{with_develop};
-    my $requirements = $prereqs->merged_requirements($phases, ['requires']);
+    my $types = [qw(requires)];
+    push @$types, 'recommends' if $self->{with_recommends};
+    push @$types, 'suggests' if $self->{with_suggests};
+    my $requirements = $prereqs->merged_requirements($phases, $types);
     my $hash = $requirements->as_string_hash;
 
     my (@package, @distribution);
