@@ -1,7 +1,7 @@
 package App::cpm::Tutorial;
 use strict;
 use warnings;
-our $VERSION = '0.306';
+our $VERSION = '0.350';
 1;
 __END__
 
@@ -26,12 +26,12 @@ From CPAN:
 
 Or, download a I<self-contained> cpm:
 
-  $ curl -sL https://git.io/cpm > cpm
+  $ curl -sL --compressed https://git.io/cpm > cpm
   $ chmod +x cpm
   $ ./cpm --version
 
   # you can even install modules without installing cpm
-  $ curl -sL https://git.io/cpm | perl - install Plack
+  $ curl -sL --compressed https://git.io/cpm | perl - install Plack
 
 =head2 First step
 
