@@ -2,7 +2,7 @@ package App::cpm::Worker::Installer;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.306';
+our $VERSION = '0.350';
 
 use App::cpm::Logger::File;
 use App::cpm::Worker::Installer::Menlo;
@@ -84,6 +84,9 @@ sub new {
         notest => $option{notest},
         sudo => $option{sudo},
         mirrors => ["https://cpan.metacpan.org/"], # this is dummy
+        configure_timeout => $option{configure_timeout},
+        build_timeout => $option{build_timeout},
+        test_timeout => $option{test_timeout},
     );
     if (my $local_lib = delete $option{local_lib}) {
         $menlo->{self_contained} = 1;
